/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome: PREV_CONS_LISTA

Descrio:
Clculo da Previso de Consumo atravs da stored procedure
PREVISAO_DE_CONSUMO_PLA, modificada para calcular para vrias filiais
(lista).

P_NRLISTAFILI  - Nmero da Lista de Filiais e Servios Concatenados
P_DTINICIAL    - Data inicial de clculo
P_DTFINAL      - Data final de clculo
P_CDPRODUTOINI - Cdigo do produto inicial (CDARVPROD)
P_CDPRODUTOFIN - Cdigo do produto final   (CDARVPROD)
P_PEACRESCIMO  - Percentual de acrscimo
P_IDARREDOND   - Opo de arredondamento.
                 Formato:
                    S - ARREDONDAMENTO DE REQUISIO
                    N - NAO ARREDONDAR
                    C - ARREDONDAMENTO DE COMPRAS
P_CDOPERADOR   - Cdigo do operador que solicitou o clculo
P_DTHRCALCPC   - Data/hora do clculo

Para aplicar:
-- @C:\Web_407\SQL\END_CONV\ORACLE\7136_PLASTPO_PREV_CONS_LISTA.SQL;

EXECUTE PREV_CONS_LISTA('0000038266', '01/05/2005', '31/05/2005', '0', 'Z', 0, 'N', '000000000999', SYSDATE)

Criao:
23/03/06 - Dmaso (p/ GR - v. 4.07)

*/

CREATE OR REPLACE
PROCEDURE PREV_CONS_LISTA
  (P_NRLISTAFILI  IN VARCHAR2,
   P_DTINICIAL    IN DATE,
   P_DTFINAL      IN DATE,
   P_CDPRODUTOINI IN VARCHAR2,
   P_CDPRODUTOFIN IN VARCHAR2,
   P_PEACRESCIMO  IN NUMBER,
   P_IDARREDOND   IN VARCHAR2,
   P_CDOPERADOR   IN VARCHAR2,
   P_DTHRCALCPC   IN DATE) IS

   V_PRXCONSPLAN VARCHAR2(20);
   V_CDSERVICO   CLOB;
BEGIN
   FOR CUR_FILIAL IN
     (SELECT DISTINCT
         SUBSTR(CDLISTA, 1, 4) AS CDFILIAL
      FROM LISTA
      WHERE
         NRLISTA = P_NRLISTAFILI
     )
   LOOP
      V_CDSERVICO := '_';

      FOR CUR_CDSERVICO IN
        (SELECT
            CDSERVFILI
         FROM SERVICO, LISTA
         WHERE
            NRLISTA = P_NRLISTAFILI AND
            SERVICO.CDFILIAL = CUR_FILIAL.CDFILIAL AND
            SERVICO.CDFILIAL||SERVICO.CDSERVFILI = CDLISTA
        )
      LOOP
         V_CDSERVICO := V_CDSERVICO||CUR_CDSERVICO.CDSERVFILI||'_';
      END LOOP; /* LOOP DOS SERVIOS */

      V_PRXCONSPLAN := '';
      NOVO_CODIGO('CONSPLAN'||CUR_FILIAL.CDFILIAL, V_PRXCONSPLAN);
      V_PRXCONSPLAN := SUBSTR(V_PRXCONSPLAN,11,10);

      PREVISAO_DE_CONSUMO_PLA(CUR_FILIAL.CDFILIAL,
                              V_CDSERVICO,
                              P_DTINICIAL,
                              P_DTFINAL,
                              P_PEACRESCIMO,
                              P_CDPRODUTOINI,
                              P_CDPRODUTOFIN,
                              P_CDOPERADOR,
                              P_DTHRCALCPC,
                              V_PRXCONSPLAN,
                              P_IDARREDOND,
                              NULL,
                              NULL);


   END LOOP;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('PREV_CONS_LISTA','0.00.000'); END;
/

